@@ -1,3 +1,12 @@
+/*
+ * Copyright (C) 2015 - 2018, Sean Davis <smd.seandavis@gmail.com>
+ *
+ * This program is free software: you can redistribute it and/or modify it under
+ * the terms of the GNU General Public License as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option) any later
+ * version. See http://www.gnu.org/copyleft/gpl.html the full text of the
+ * license.
+ */
 
 #ifndef GREETER_CONFIGURATION_H
 #define GREETER_CONFIGURATION_H
@@ -28,6 +37,7 @@
 #define CONFIG_KEY_PANEL_POSITION       "panel-position"
 #define CONFIG_KEY_KEYBOARD_POSITION    "keyboard-position"
 #define CONFIG_KEY_A11Y_STATES          "a11y-states"
+#define CONFIG_KEY_AT_SPI_ENABLED       "at-spi-enabled"
 
 #define CONFIG_GROUP_MONITOR            "monitor:"
 #define CONFIG_KEY_BACKGROUND           "background"
